Board Version History
=====================

This history gives you a version overview of the zerocat chipflasher board,
which is represented by the file `hardware/gschem/board.sch`, but which may
be represented by other files as well, in future.


Board Version Scheme
--------------------

    board-v<major>.<minor>.<revision>.<commit-hash>

@note
There may be exceptions, which do not follow the Board Version Scheme.

Tags are using the first three numbers only.

  - major

    Hardware has changed. The resulting product is a major change or
    upgrade. You will need to upgrade your firmware and/or equipment due
    to incompatibilities with the previous version.

  - minor

    Onboard hardware has changed. Additional functionality or new features are
    introduced.

  - revision

    No changes of onboard hardware. Bug fixes, minor changes, graphical stuff.
    However, plugs or cabling may have changed.

  - commit-hash

    Optional. Sometimes, if you need to specify a commit id as an exact
    reference, please just append the abbreviated commit-hash to the
    version number.


board-edition-1
---------------

@note In case this version number has no corresponding tag within the
repository yet, just use the tip of branch _go-for-board-edition-1_
as reference.

General info:

  - **We continue to use the unmodified PCB of version 'board-v1.1.0'.**

  - This board version works best in conjunction with software 'v0.4.3',
    please compare to [Version History][].

  - The file `hardware/doc/Makefile` has been improved:
    - .PHONY has been updated
    - long comments with line breaks in gschem files are now supported
    - targets have been simplified by using automatic variables

Upgraded comments in `hardware/gschem/board.sch`:

  - Add a comment about upgraded Polyfuse in file `hardware/gschem/board.sch`.
  - An unused pin of the RS232 driver should be tied to GND. The
    documentation now suggests a manual bug fix.
  - Add a comment about missing pcb heatsink copper area.

Device upgrades as drop-in replacements in `hardware/gschem/board.sch`
allow us to access the sysboard of a ThinkPad T60 while access to a
ThinkPad X60/X60s sysboard now works more reliable as well:

  - Upgrade the capacitor that supports the SPI Power Line to 1000µF.
  - Upgrade the Polyfuse to RXEF075, I_hold = 750mA, I-trip = 1500mA.


board-v1.1.3
------------

  - We merge in all improvements of the branch
    _go-for-board-edition-1_ while _not_ using the tag
    **board-edition-1** within the git repository itself, yet. This
    gives us room to fix and complete the documentation until that tag
    is finally placed.  Note chipflashers shown on photos are already
    labelled with a **board-edition-1** sticker, however.

  - We add the file front-panel.dxf to the list of source files.

  - We continue to use the pcb of version _board-v1.1.0_.

  - We continue to use the software version _v0.3.0_.


board-v1.1.2
------------

The file hardware/pcb/board.pcb has been reverted to version 'board-v1.1.0'
which allows us to use already manufactured PCBs in conjunction with updated
files and front-label version tags.


board-v1.1.1
------------

  - We used to use a MAX232 chip which is not explicitly rated for a 3V Power Supply,
    therefore hardware/gschem/board.sch and hardware/gschem/board-dev.sch have been
    updated with a 3V compatible device like the MAX3232CPE+. This chip allows a smaller
    blocking capacitor and smaller charge pump capacitors as well.

  - Clearance of some forgotten vias has been adjusted to 15mil.

  - A spike shaped route has been improved.

  - Board’s version number in the pcb layout file has been set to board-v1.1.1.


board-v1.1.0
------------

A second linear power regulator has been added, which seperates the Propeller’s supply from that of the SPI bus. That way, the chipflasher is independend from power failure due to high
inrush currents when the target sysboard is powered.

That allows as well to enable the Propeller’s built-in Brown-Out-Detection: Pins keep a well
defined level even if the supply voltage is not certain, a very usual situation during
power-off.

Furthermore, a simple overcurrent and overvoltage protection has been added right behind the
USB power entry. A Polyfuse is used, which limits the maximal USB current to about 1000mA.
Currents of up to 500mA are well in range, which is enough for all tested boards except the ThinkPad-X60s sysboard. However, the latter still can be flashed although current consumption is throttled to around 700mA by the Polyfuse. (Note that the related developer board (board-dev.sch) is equipped with a 0.025Ohms PowerShunt which facilitates overall current measurement.)

This version ships with an elaborated pcb layout file, which is untested by the time of writing.

To ease pcb layout, two pins have been twisted, thus requiring the updated firmware
version v0.3.0 (See [Version History][] for details.)


board-v1.0.5
------------

The pnp transistor has been replaced by a pnp MOSFET, because when flashing
the X220 the transistor gets too hot.


board-v1.0.4
------------

Add standard SPI chip layout examples, which are handy to have available when
connecting the SPI-Cable.


board-v1.0.3
------------

Small bug fix: A junction had been misplaced.


board-v1.0.2
------------

Generate new devices numbers, they will be used in the bill of materials (bom.md).


board-v1.0.1
------------

Update SPI cable to new SPI connector layout.


board-v1.0.0
------------

This board supports more sysboards.

  - two port pins for sinking CE#
  - different propeller pin function layout
  - adjustable CE# pull-up
  - SPI connector is 9x1 again, but layout has changed
  - different base network of pnp transistor
  - big cap for SPI power (in conjunction with protection diodes from board-v0.4.0)

This board requires a firmware update.


board-v0.4.0
------------

Board with protection diodes across power regulator,
in preparation for next board version.


board-v0.3.10
-------------

First Tandem-Workshop.
Board with different SPI connector, uses 5x2 pinheader.


board-v0.3.0
------------

Starts from RAM as well.


board-v0.2.0
------------

Reset line is DTR or RTS (optional).


board-v0.1.8
------------

First board that has been shipped for testing.


board-v0.1.0
------------

  - starts from ROM only
  - uses 9x2 pinheader SPI connector


board-v0.0.0
------------

Initial board.



[Version History]:    version-history.md


-----------------------------------------------------------------------

  @copyright
  Copyright (C) 2017, 2018 Kai Mertens <kmx@posteo.net> @n
  Permission is granted to copy, distribute and/or modify this document
  under the terms of the GNU Free Documentation License, Version 1.3
  or any later version published by the Free Software Foundation;
  with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
  A copy of the license is included in the section entitled:
  [GNU Free Documentation License](COPYING-DOCUMENTATION.md)
