#!/bin/bash
#
# Zerocat Chipflasher --- Flash free firmware to BIOS chips,
#                         kick the Manageability Engine.
#
# Copyright (C) 2017, 2018 Kai Mertens <kmx@posteo.net>
#
# The Zerocat Chipflasher is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Zerocat Chipflasher is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This file is part of the Zerocat Chipflasher.
#
# bin2srec.sh
#
# Convert binary data into lines of Motorola S-Record.
#
# usage: ./bin2srec.sh in.bin out.srec
#   in.bin:     raw binary file
#   out.srec:   text file with lines of Motorola S-Record
#

PAYLOAD_BASE=0x10
FF_RUNLENGTH=0x10

# Let's assume we deal with chips greater than 64K.
# Please compare to: firmware/src/filespec.c, inline int payload()
PAYLOAD=$(($PAYLOAD_BASE << 2));

echo $0 "-- Convert binary data into lines of Motorola S-Record.";

if ( ! [ "${1}" ] || ! [ "${2}" ] );
then
  echo;
  echo $0" usage:";
  echo "  bash "$0" in.bin out.srec";
  echo "  in.bin:     A binary ROM image.";
  echo "  out.srec:   A text file in Motorola-S file format.";
  echo;
  exit 0;
fi

if ( ! [ -a $1 ] );
then
  echo "Input file "$1" doesn't exist. Exiting.";
  exit 1;
fi

if [ -a $2 ];
then
  echo "Output file "$2" already exists. Exiting.";
  exit 1;
fi

srec_cat $1 -raw -uf 0xff $FF_RUNLENGTH -o $2 -m -obs $PAYLOAD -esa 0x00;
if [ "$?" -eq 0 ];
then
  echo "S-Record data has been successfully written to: "$2;
else
  echo "An error occurred. Exiting.";
  exit 1;
fi

exit 0;
