#!/bin/bash
#
# Zerocat Chipflasher --- Flash free firmware to BIOS chips,
#                         kick the Manageability Engine.
#
# Copyright (C) 2017, 2018 Kai Mertens <kmx@posteo.net>
#
# The Zerocat Chipflasher is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Zerocat Chipflasher is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This file is part of the Zerocat Chipflasher.
#
# diff-srec.sh
#
# Use the diff command to check whether two S-record files match each other.
#
# usage: bash diff-srec.sh in1.srec in2.srec
#   in1.srec:    A text file in Motorola S-record format
#   in2.srec:    Another text file in Motorola S-record format
#

echo $0" -- Use the diff command to check whether data of two S-record files matches each other.";

if ( ! [ "${1}" ] || ! [ "${2}" ] )
then
  echo
  echo $0" usage:"
  echo "  "$0" in1.srec in2.srec"
  echo "  in1.srec:   A text file in Motorola-S file format."
  echo "  in2.srec:   Another text file in Motorola-S file format."
  echo
  exit 0;
fi

if ( ! [ -a $1 ] );
then
  echo "Input file "$1" doesn't exist. Exiting.";
  exit 1;
fi

if ( ! [ -a $2 ] );
then
  echo "Input file "$2" doesn't exist. Exiting.";
  exit 1;
fi

SREC1=mktemp;
if [ "$?" -ne 0 ];
then
  echo "An error while creating a temporary file. Exiting.";
  exit 1;
fi

SREC2=mktemp;
if [ "$?" -ne 0 ];
then
  echo "An error while creating a temporary file. Exiting.";
  exit 1;
fi

srec_cat $1 -uf 0xff -o SREC1 -m -do;
if [ "$?" -ne 0 ];
then
  rm -f SREC1;
  echo "An error occured. Exiting.";
  exit 1;
fi

srec_cat $2 -uf 0xff -o SREC2 -m -do;
if [ "$?" -ne 0 ];
then
  rm -f SREC2;
  echo "An error occured. Exiting.";
  exit 1;
fi

diff -y SREC1 SREC2;
if [ "$?" -eq 0 ];
then
  echo "Data of files "$1" and "$2" does NOT differ."
else
  echo "Data of files "$1" and "$2" differs!"
fi

rm -f SREC1
rm -f SREC2

exit 0
